@@ -1,8 +1,8 @@
 # encoding: utf-8
 
 from cool.admin.admin import (
-    BaseModelAdmin, StrictInlineFormSet, StrictModelFormSet, admin_register,
-    site_register,
+    AutoCompleteMixin, BaseModelAdmin, StrictInlineFormSet, StrictModelFormSet,
+    admin_register, site_register,
 )
 from cool.admin.filters import (
     AutocompleteFieldFilter, ContainsFilter, DateRangeFieldFilter,
@@ -11,7 +11,8 @@ from cool.admin.filters import (
 )
 
 __all__ = [
-    'BaseModelAdmin', 'StrictInlineFormSet', 'StrictModelFormSet', 'site_register', 'admin_register',
+    'AutoCompleteMixin', 'BaseModelAdmin', 'StrictInlineFormSet', 'StrictModelFormSet',
+    'site_register', 'admin_register',
     'AutocompleteFieldFilter', 'ContainsFilter', 'DateRangeFieldFilter', 'IContainsFilter', 'ISearchFilter',
     'IStartswithFilter', 'NumberRangeFieldFilter', 'SearchFilter', 'StartswithFilter',
 ]
