@@ -1,11 +1,12 @@
 # encoding: utf-8
-
+import warnings
 from functools import reduce, wraps
 
 import django
 from django import forms
 from django.contrib import admin
 from django.contrib.admin.utils import flatten_fieldsets
+from django.contrib.admin.views import main
 from django.contrib.admin.widgets import AdminFileWidget
 from django.contrib.auth import get_permission_codename
 from django.core.exceptions import (
@@ -13,6 +14,7 @@ from django.core.exceptions import (
 )
 from django.core.validators import EMPTY_VALUES
 from django.db import models
+from django.db.models import ManyToOneRel
 from django.db.models.constants import LOOKUP_SEP
 from django.db.models.fields.related import RelatedField
 from django.forms.models import (
@@ -25,6 +27,7 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import gettext_lazy as _
 
 from cool.admin import widgets
+from cool.core.deprecation import RemovedInDjangoCool20Warning
 from cool.settings import cool_settings
 
 
@@ -140,7 +143,7 @@ def get_related_model_fields(model, rel, is_foreign_key):
 
 class FormSetMixin:
     """
-    Add validation to ensure POST data is up to date
+    添加验证以确保数据是最新的
     """
     def _existing_object(self, pk):
         if not hasattr(self, '_object_dict'):
@@ -188,7 +191,7 @@ class FormSetMixin:
                 queryset=self.queryset,
             )
             self.forms = new_formset.forms
-            raise ValidationError('页面数据已经更新，请修改后重新保存')
+            raise ValidationError(_('Page data has been updated, please modify and save again'))
 
 
 class StrictModelFormSet(FormSetMixin, BaseModelFormSet):
@@ -212,13 +215,76 @@ class AdminImageWidget(AdminFileWidget):
         return mark_safe(''.join(output))
 
 
-class BaseModelAdmin(admin.ModelAdmin):
+class AutoCompleteMixin:
+
+    def formfield_for_foreignkey(self, db_field, request, **kwargs):
+        db = kwargs.get('using')
+        if ('widget' not in kwargs
+                and cool_settings.ADMIN_FOREIGNKEY_FIELD_USE_AUTOCOMPLETE
+                and hasattr(db_field.remote_field.model, 'get_search_fields')
+                and db_field.name not in [*self.raw_id_fields, *self.radio_fields]):
+            kwargs['widget'] = widgets.CoolAutocompleteSelect(db_field, self.admin_site, using=db)
+        return super().formfield_for_foreignkey(db_field, request, **kwargs)
+
+    def formfield_for_manytomany(self, db_field, request, **kwargs):
+        db = kwargs.get('using')
+        if ('widget' not in kwargs
+                and cool_settings.ADMIN_MANYTOMANY_FIELD_USE_AUTOCOMPLETE
+                and hasattr(db_field.remote_field.model, 'get_search_fields')
+                and db_field.name not in [*self.raw_id_fields, *self.filter_vertical, *self.filter_horizontal]):
+            kwargs['widget'] = widgets.CoolAutocompleteSelectMultiple(db_field, self.admin_site, using=db)
+        if django.VERSION >= (3, 1) or 'widget' not in kwargs:
+            return super().formfield_for_manytomany(db_field, request, **kwargs)
+        else:
+            if not db_field.remote_field.through._meta.auto_created:
+                return None
+            if 'queryset' not in kwargs:
+                queryset = self.get_field_queryset(db, db_field, request)
+                if queryset is not None:
+                    kwargs['queryset'] = queryset
+
+            form_field = db_field.formfield(**kwargs)
+            return form_field
+
+    def get_search_fields(self, request):
+        search_fields = super().get_search_fields(request)
+        get_search_fields_func = getattr(self.opts.model, 'get_search_fields', None)
+        if get_search_fields_func and callable(get_search_fields_func):
+            return tuple(set(get_search_fields_func()) | set(search_fields))
+        return ()
+
+
+class AutoSetRelatedFieldChangeList(main.ChangeList):
+
+    def apply_select_related(self, qs):
+        if self.list_select_related is False:
+            related_fields = self.get_related_field_in_list_display()
+            if related_fields:
+                return qs.select_related(*related_fields)
+        return super().apply_select_related(qs)
+
+    def get_related_field_in_list_display(self):
+        ret = []
+        for field_name in self.list_display:
+            try:
+                field = self.lookup_opts.get_field(field_name)
+            except FieldDoesNotExist:
+                pass
+            else:
+                if isinstance(field.remote_field, ManyToOneRel):
+                    if field_name != field.get_attname():
+                        ret.append(field_name)
+        return ret
+
+
+class BaseModelAdmin(AutoCompleteMixin, admin.ModelAdmin):
     """
     自定义Admin基类，列表页显示默认字段，支持自定义功能
     """
 
     # remove "__str__"
     list_display = []
+    list_display_links = ['id', ]
 
     # Extend options to manage site
     # extend field exclude RelatedField and PrimaryKey fields into list_display
@@ -226,12 +292,14 @@ class BaseModelAdmin(admin.ModelAdmin):
     with_related_items = True
     extend_normal_fields = True
     extend_related_fields = False
+    auto_set_list_select_related = True
     exclude_list_display = []
     heads = ['id', ]
     tails = []
     # manage Add/Change view
     addable = True
-    changeable = True
+    changeable = None
+    editable = True
     deletable = True
     # manage Change view
     change_view_readonly_fields = []
@@ -262,6 +330,16 @@ class BaseModelAdmin(admin.ModelAdmin):
         # not dynamic lookup, default behaviour
         return self.__getattribute__(attr)
 
+    def get_editable(self):
+        if self.changeable is not None:
+            warnings.warn(
+                "The changeable argument is deprecated in favor of editable",
+                RemovedInDjangoCool20Warning,
+                stacklevel=2
+            )
+            self.editable = self.changeable
+        return self.editable
+
     def formfield_for_dbfield(self, db_field, **kwargs):
         if cool_settings.ADMIN_SHOW_IMAGE_IN_FORM_PAGE and isinstance(db_field, models.ImageField):
             kwargs.pop("request", None)
@@ -270,7 +348,7 @@ class BaseModelAdmin(admin.ModelAdmin):
         return super().formfield_for_dbfield(db_field, **kwargs)
 
     def get_changeable_fields(self, request, obj=None):
-        if not self.changeable:
+        if not self.get_editable():
             return ()
         if self.changeable_fields == forms.ALL_FIELDS:
             return None
@@ -283,7 +361,7 @@ class BaseModelAdmin(admin.ModelAdmin):
         return self.deletable and super().has_delete_permission(request, obj)
 
     def has_change_permission(self, request, obj=None):
-        return self.changeable and super().has_change_permission(request, obj)
+        return self.get_editable() and super().has_change_permission(request, obj)
 
     def has_add_permission(self, request):
         return self.addable and super().has_add_permission(request)
@@ -291,42 +369,6 @@ class BaseModelAdmin(admin.ModelAdmin):
     def get_user_queryset(self, queryset):
         return queryset
 
-    def formfield_for_foreignkey(self, db_field, request, **kwargs):
-        db = kwargs.get('using')
-        if ('widget' not in kwargs
-                and cool_settings.ADMIN_FOREIGNKEY_FIELD_USE_AUTOCOMPLETE
-                and hasattr(db_field.remote_field.model, 'get_search_fields')
-                and db_field.name not in [*self.raw_id_fields, *self.radio_fields]):
-            kwargs['widget'] = widgets.CoolAutocompleteSelect(db_field.remote_field, self.admin_site, using=db)
-        return super().formfield_for_foreignkey(db_field, request, **kwargs)
-
-    def formfield_for_manytomany(self, db_field, request, **kwargs):
-        db = kwargs.get('using')
-        if ('widget' not in kwargs
-                and cool_settings.ADMIN_MANYTOMANY_FIELD_USE_AUTOCOMPLETE
-                and hasattr(db_field.remote_field.model, 'get_search_fields')
-                and db_field.name not in [*self.raw_id_fields, *self.filter_vertical, *self.filter_horizontal]):
-            kwargs['widget'] = widgets.CoolAutocompleteSelectMultiple(db_field.remote_field, self.admin_site, using=db)
-        if django.VERSION >= (3, 1) or 'widget' not in kwargs:
-            return super().formfield_for_manytomany(db_field, request, **kwargs)
-        else:
-            if not db_field.remote_field.through._meta.auto_created:
-                return None
-            if 'queryset' not in kwargs:
-                queryset = self.get_field_queryset(db, db_field, request)
-                if queryset is not None:
-                    kwargs['queryset'] = queryset
-
-            form_field = db_field.formfield(**kwargs)
-            return form_field
-
-    def get_search_fields(self, request):
-        search_fields = super().get_search_fields(request)
-        get_search_fields_func = getattr(self.opts.model, 'get_search_fields', None)
-        if get_search_fields_func and callable(get_search_fields_func):
-            return tuple(set(get_search_fields_func()) | set(search_fields))
-        return ()
-
     def get_form(self, request, obj=None, **kwargs):
         if 'fields' in kwargs:
             fields = kwargs.get('fields')
@@ -468,7 +510,7 @@ class BaseModelAdmin(admin.ModelAdmin):
 
     def get_list_display(self, request, in_change_view=True):
         """
-        get all fields except PK and Relations if extend_normal_fields is True
+        get all fields except Relations if extend_normal_fields is True
         """
 
         list_display = list(super().get_list_display(request))
@@ -523,6 +565,17 @@ class BaseModelAdmin(admin.ModelAdmin):
             field_names.append('get_all_relations')
         return field_names
 
+    def get_list_display_links(self, request, list_display):
+        list_display_links = super().get_list_display_links(request, list_display)
+        if list_display and not set(list_display_links) & set(list_display):
+            return list(list_display)[:1]
+        return list_display_links
+
+    def get_changelist(self, request, **kwargs):
+        if self.auto_set_list_select_related:
+            return AutoSetRelatedFieldChangeList
+        return super().get_changelist(request, **kwargs)
+
     def get_normal_fields(self):
         fields = []
         exclude = self.exclude or ()
@@ -583,23 +636,30 @@ def check_perms(*perms):
 
 
 def site_register(model_or_iterable, admin_class=None, site=None, **options):
+    """
+    将model通过admin_class注册到后台管理中，admin_class不传默认使用BaseModelAdmin
+    """
     if site is None:
         site = admin.site
     if admin_class is None:
         admin_class = BaseModelAdmin
-    site.register(model_or_iterable, admin_class, **options)
+    if cool_settings.ADMIN_SITE_REGISTER_FILTER_FUNCTION is not None:
+        if not isinstance(model_or_iterable, (list, tuple, set)):
+            model_or_iterable = [model_or_iterable]
+        for model in model_or_iterable:
+            new_options = cool_settings.ADMIN_SITE_REGISTER_FILTER_FUNCTION(
+                model, admin_class=admin_class, site=site, **options
+            )
+            new_options.pop('admin_class', None)
+            new_options.pop('site', None)
+            site.register(model_or_iterable, admin_class, **new_options)
+    else:
+        site.register(model_or_iterable, admin_class, **options)
 
 
 def admin_register(func=None, *, admin_class=None, site=None, **options):
     """
-    Register the given model(s) classes and wrapped ModelAdmin class with
-    admin site:
-
-    @admin_register()
-    class Author(models.BaseModel):
-        pass
-
-    The `site` kwarg is an admin site to use instead of the default admin site.
+    model装饰器，使用后将model通过admin_class注册到后台管理中
     """
 
     def _model_admin_wrapper(model_class):
